@@ -198,6 +198,23 @@ public:
   inline auto device_id() const noexcept -> int { return stream_.device_id(); }
 
   auto forward() -> void override {
+#ifdef SPFFT_ROCM
+    // workaround for bug with rocFFT for case 1x1xZ
+    if (spaceDomain_.dim_mid() == 1 && spaceDomain_.dim_inner() == 1) {
+      // make sure imaginary part is 0
+      gpu::check_status(gpu::memset_async(
+          static_cast<void*>(freqDomain_.data()), 0,
+          freqDomain_.size() * sizeof(typename decltype(freqDomain_)::ValueType), stream_.get()));
+      // copy real valued data into complex buffer -> from stride 1 to stride 2
+      gpu::check_status(gpu::memcpy_2d_async(static_cast<void*>(freqDomain_.data()), 2 * sizeof(T),
+                                             static_cast<const void*>(spaceDomain_.data()),
+                                             sizeof(T), sizeof(T), freqDomain_.dim_outer(),
+                                             gpu::flag::MemcpyDeviceToDevice, stream_.get()));
+      // no transform needed
+      return;
+    }
+#endif
+
     if(symm_) {
       // Make sure buffer is zero before transform, such that the symmtry operation can identify
       // elements, which have not been written to by the FFT
@@ -213,6 +230,19 @@ public:
   }
 
   auto backward() -> void override {
+#ifdef SPFFT_ROCM
+    // workaround for bug with rocFFT for case 1x1xZ
+    if (spaceDomain_.dim_mid() == 1 && spaceDomain_.dim_inner() == 1) {
+      // copy complex data into real valued buffer -> from stride 2 to stride 1
+      gpu::check_status(gpu::memcpy_2d_async(static_cast<void*>(spaceDomain_.data()), sizeof(T),
+                                             static_cast<const void*>(freqDomain_.data()),
+                                             2 * sizeof(T), sizeof(T), freqDomain_.dim_outer(),
+                                             gpu::flag::MemcpyDeviceToDevice, stream_.get()));
+      // no transform needed
+      return;
+    }
+#endif
+
     gpu::fft::check_result(gpu::fft::set_work_area(planBackward_, workBuffer_->data()));
     gpu::fft::check_result(
         gpu::fft::execute(planBackward_, freqDomain_.data(), spaceDomain_.data()));
